<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/*
Plugin Name: WooCommerce Eximbay Payment Gateway
Plugin URI: http://www.eximbay.com
Description: Eximbay Payment gateway for woocommerce
Version: 1.0
Author: Uuganbayar Choijiljav
Author URI: http://www.eximbay.com
*/
load_plugin_textdomain( 'woocommerce_eximbay', false, $plugin_dir . '/languages/' );

add_action('plugins_loaded', 'woocommerce_eximbay_init', 0);

function woocommerce_eximbay_init(){
  if(!class_exists('WC_Payment_Gateway')) return;
class WC_Gateway_Eximbay extends WC_Payment_Gateway {

    /**
     * Constructor for the gateway.
     *
     * @access public
     * @return void
     */
	public function __construct() {
		global $woocommerce;

		$plugin_dir = plugin_dir_url(__FILE__);

        $this->id           = 'eximbay';
		$this->icon = apply_filters('woocommerce_eximbay_icon', ''.$plugin_dir.'logo-pay.gif');
        $this->has_fields   = false;
        $this->liveurl      = 'https://www.eximbay.com/web/payment2.0/payment_real.do';
		$this->testurl      = 'http://www.test2.eximbay.com/web/payment2.0/payment_real.do';
        $this->method_title = __( 'Eximbay', 'woocommerce' );

		// Load the settings.
		$this->init_form_fields();
		$this->init_settings();

		// Define user set variables
		$this->title 			= $this->get_option( 'title' );
		$this->description 		= $this->get_option( 'description' );
		$this->merchant			= $this->get_option( 'merchant' );
		$this->mid				= $this->get_option( 'mid' );
		$this->secretKey		= $this->get_option( 'secretKey' );
		$this->testmode			= $this->get_option( 'testmode' );
		$this->status_page_id	= $this->get_option( 'status_page_id' );
	
		// Actions
		add_action( 'valid-eximbay-request', array( $this, 'successful_request' ) );
		add_action( 'woocommerce_receipt_eximbay', array( $this, 'receipt_page' ) );
		add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );

		//Payment listener/API hook
		add_action( 'woocommerce_api_wc_gateway_eximbay', array( $this, 'check_response' ) );

		if ( !$this->is_valid_for_use() ) $this->enabled = false;
    }


    /**
     * Check if this gateway is enabled and available in the user's country
     *
     * @access public
     * @return bool
     */
    function is_valid_for_use() {
        if ( ! in_array( get_woocommerce_currency(), apply_filters( 'woocommerce_eximbay_supported_currencies', array( 'AUD', 'CAD', 'CNY', 'EUR', 'GBP', 'HKD', 'JPY', 'KRW', 'RUB', 'SGD', 'THB', 'TWD', 'USD' ) ) ) ) return false;

        return true;
    }

	/**
	 * Admin Panel Options
	 * - Options for bits like 'title' and availability on a country-by-country basis
	 *
	 * @since 1.0.0
	 */
	public function admin_options() {

		?>
		<h3><?php _e( 'Eximbay Gateway', 'woocommerce' ); ?></h3>
		<p><?php _e( 'Exibmay Gateway works by sending the user to Eximbay to enter their payment information.', 'woocommerce' ); ?></p>

    	<?php if ( $this->is_valid_for_use() ) : ?>

			<table class="form-table">
			<?php
    			// Generate the HTML For the settings form.
    			$this->generate_settings_html();
			?>
			</table><!--/.form-table-->

		<?php else : ?>
            <div class="inline error"><p><strong><?php _e( 'Gateway Disabled', 'woocommerce' ); ?></strong>: <?php _e( 'Eximbay does not support your store currency.', 'woocommerce' ); ?></p></div>
		<?php
			endif;
	}


    /**
     * Initialise Gateway Settings Form Fields
     *
     * @access public
     * @return void
     */
    function init_form_fields() {

    	$this->form_fields = array(
			'enabled' => array(
							'title' => __( 'Enable/Disable', 'woocommerce' ),
							'type' => 'checkbox',
							'label' => __( 'Enable Eximbay Payment Gateway', 'woocommerce' ),
							'default' => 'yes'
						),
			'title' => array(
							'title' => __( 'Title', 'woocommerce' ),
							'type' => 'text',
							'description' => __( 'This controls the title which the user sees during checkout.', 'woocommerce' ),
							'default' => __( 'Eximbay', 'woocommerce' ),
							'desc_tip'      => true,
						),
			'description' => array(
							'title' => __( 'Description', 'woocommerce' ),
							'type' => 'textarea',
							'description' => __( 'This controls the description which the user sees during checkout.', 'woocommerce' ),
							'default' => __( 'Pay via Eximbay; you can pay with your credit card if you don\'t have a Eximbay account', 'woocommerce' )
						),
			'merchant' => array(
							'title' => __('Merchant Name', 'woocommerce'),
							'type' => 'text',
							'description' => __('Enter your merchant name.')
						),
			'mid' => array(
							'title' => __('Merchant ID', 'woocommerce'),
							'type' => 'text',
							'description' => __('Merchant ID at Eximbay.')
						),
            'secretKey' => array(
							'title' => __('Secret Key', 'woocommerce'),
							'type' => 'text',
							'description' =>  __('Given to Merchant by Eximbay', 'eximbay')
						),
			'testing' => array(
							'title' => __( 'Gateway Testing', 'woocommerce' ),
							'type' => 'title',
							'description' => '',
						),
			'testmode' => array(
							'title' => __( 'Eximbay Test Mode', 'woocommerce' ),
							'type' => 'checkbox',
							'label' => __( 'Enable Test Mode', 'woocommerce' ),
							'default' => 'yes',
							'description' => __( 'Eximbay Test URL can be used to test payments.', 'woocommerce' )
						),
			 'status_page_id' => array(
							'title' => __('Status Page'),
							'type' => 'select',
							'options' => $this -> get_pages('Select Page'),
							'description' => "URL of status page"
						)
			);

    }


	/**
	 * Get Eximbay Args for passing Payment Processing
	 *
	 * @access public
	 * @param mixed $order
	 * @return array
	 */
	function get_eximbay_args( $order ) {
		global $woocommerce;

		$order_id = $order->id;

		$ref = $order_id.'_'.date("ymdHis");
		
		$cur = get_woocommerce_currency();
		$amt = $order->get_order_total();  //$order->get_total()

		$linkBuf = $this->secretKey. "?mid=" . $this->mid ."&ref=" . $ref ."&cur=" .$cur ."&amt=" .$amt;
		$fgkey = md5($linkBuf);
		
		$item_name = '';
		if ( sizeof( $order->get_items() ) > 0 ) {
			foreach ( $order->get_items() as $item ) {
				$product = $order->get_product_from_item( $item );
				$item_name 	.= $item['name'] . ' ';
			}
		}

		$return_url = str_replace( 'https:', 'http:', add_query_arg( 'wc-api', 'WC_Gateway_Eximbay', home_url( '/' ) ) );
		$status_url = ($this -> status_page_id=="" || $this -> status_page_id==0)?get_site_url() . "/":get_permalink($this -> status_page_id);

		// Eximbay Args
		$eximbay_args = array(
				'mid' 					=> $this->mid,
				'ref' 					=> $ref,
				'fgkey' 				=> $fgkey,
				'cur'			 		=> $cur,
				'amt'					=> $amt,
				'product'				=> $item_name,
				'param1'				=> '',
				'param2'				=> '',
				'param3'				=> '',
				'buyer'					=> $order->billing_first_name.' '.$order->billing_last_name,
				'email'					=> $order->billing_email,
				'tel'					=> $order->billing_phone,
				'charset' 				=> 'UTF-8',
				'shop'					=> $this->merchant,
				'lang' 					=> 'EN',
				'returnurl' 			=> $return_url,
				'statusurl'				=> $status_url,
				'directToReturn'		=> 'N'
		);

		$eximbay_args = apply_filters( 'woocommerce_eximbay_args', $eximbay_args );

		return $eximbay_args;
	}


    /**
	 * Generate the eximbay button link
     *
     * @access public
     * @param mixed $order_id
     * @return string
     */
    function generate_eximbay_form( $order_id ) {
		global $woocommerce;

		$order = new WC_Order( $order_id );

		if ( $this->testmode == 'yes' ):
			$eximbay_adr = $this->testurl;
		else :
			$eximbay_adr = $this->liveurl;
		endif;

		$eximbay_args = $this->get_eximbay_args( $order );

		$eximbay_args_array = array();

		foreach ($eximbay_args as $key => $value) {
			$eximbay_args_array[] = '<input type="hidden" name="'.esc_attr( $key ).'" value="'.esc_attr( $value ).'" />';
		}

		return '<form action="'.esc_url( $eximbay_adr ).'" method="post" id="eximbay_payment_form">
				' . implode( '', $eximbay_args_array) . '
				<input type="submit" class="button-alt" id="submit_eximbay_payment_form" value="'.__( 'Pay via Eximbay', 'woocommerce' ).'" /> <a class="button cancel" href="'.esc_url( $order->get_cancel_order_url() ).'">'.__( 'Cancel order &amp; restore cart', 'woocommerce' ).'</a>
				
				<script type="text/javascript">
					jQuery(function(){
						jQuery("#eximbay_payment_form").submit(function(){
							var xTop = 200;
							window.open("", "payment2", "scrollbars=yes,status=no,toolbar=no,resizable=yes,location=no,menu=no,width=800,height=470,top=200,left=300");
							this.target = "payment2";
						});
					});
				</script>

				</form>';

	}


    /**
     * Process the payment and return the result
     *
     * @access public
     * @param int $order_id
     * @return array
     */
	function process_payment( $order_id ) {

		$order = new WC_Order( $order_id );
		
		return array(
			'result' 	=> 'success',
			'redirect'	=> add_query_arg('order', $order->id, add_query_arg('key', $order->order_key, get_permalink(woocommerce_get_page_id('pay' ))))
		);
	}


    /**
     * Output for the order received page.
     *
     * @access public
     * @return void
     */
	function receipt_page( $order ) {

		echo '<p>'.__( 'Thank you for your order, please click the button below to pay with Exibmay.', 'woocommerce' ).'</p>';

		echo $this->generate_eximbay_form( $order );

	}


	/*
     * Send the payment data to the gateway server and return the response.
     */
    function check_request_is_valid() {
      global $woocommerce;
	 	 
	  // Get url
      if ( $this->testmode == 'yes' ):
		 $eximbay_adr = $this->testurl;		
	  else :
		 $eximbay_adr = $this->liveurl;		
	  endif;

	   // Send request
      $response = wp_remote_post( $eximbay_adr, array(
          'body'  => $_POST,
         )
      );
      
      // Quit if it didn't work
      if ( is_wp_error( $response ) ) {
        $woocommerce->add_error( __( 'Problem connecting to server at ', 'woocommerce' ) . $eximbay_adr . ' ( ' . $response->get_error_message() . ' )' );
        return false;
      }

	  return true;   
    }
	
	/**
	 * Check for Eximbay Response
	 *
	 * @access public
	 * @return void
	 */
	function check_response() {

		@ob_clean();

    	$_POST = stripslashes_deep( $_POST );

    	if ( $this->check_request_is_valid() ) {

        	do_action( "valid-eximbay-request", $_POST );

		} else {

			wp_die( "Eximbay IPN Request Failure" );

   		}

	}


	/**
	 * Successful Payment!
	 *
	 * @access public
	 * @param array $posted
	 * @return void
	 */
	function successful_request($posted) {
		global $woocommerce;
		
	    if ( ! empty( $posted['ref'] ) ) {
			
			$order_id_time = $posted['ref'];
			$order_id = explode('_', $posted['ref']);
			$order_id = (int)$order_id[0];
			
			if($order_id != ''){
				try
				{
					$order = new WC_Order( $order_id );
					
					$mid = $posted['mid'];
					$ref = $posted['ref'];
					$cur = $posted['cur'];
					$amt = $posted['amt'];
					$shop = $posted['shop'];
					$buyer = $posted['buyer'];
					$tel = $posted['tel'];
					$email = $posted['email'];
					$product = $posted['product'];
					$lang = $posted['lang'];
					$param1 = $posted['param1'];
					$param2 = $posted['param2'];
					$param3 = $posted['param3'];
					
					
					$transid = $posted['transid'];
					$rescode = $posted['rescode'];
					$resmsg = $posted['resmsg'];
					$authcode = $posted['authcode'];
					$cardco = $posted['cardco'];
					$resdt = $posted['resdt'];
					$fgkey = $posted['fgkey'];
					
											
					if ($rescode == '0000')
					{	

							$linkBuf = $this->secretKey. "?mid=" . $mid ."&ref=" . $ref ."&cur=" .$cur ."&amt=" .$amt ."&rescode=" .$rescode ."&transid=" .$transid;
							$newFgkey = md5($linkBuf);

							if(strtolower($fgkey) != $newFgkey){
								 $order -> update_status('failed');
								 $order -> add_order_note('Security Error. Illegal access detected');
							}
							else
							{                           
								$order -> payment_complete();
                                $order -> add_order_note('Eximbay payment successful.<br/>Unnique Id from Eximbay: '.$posted['transid']);
                                $woocommerce -> cart -> empty_cart();
								$redirect_url = esc_url( $this->get_return_url( $order ));
								echo $this->redirect($order, $redirect_url);
							}
					}
					else
					{
                            $order -> add_order_note('Transaction Declined: '.$posted['rescode'].'-'.$posted['resmsg']);
							$woocommerce->add_error( __( 'Sorry, the transaction was declined.', 'woocommerce' ) );
							$redirect_url = esc_url( $order->get_cancel_order_url());
							echo $this->redirect($order, $redirect_url);
					}
								
				}catch(Exception $e){
                }

	        }
				exit;
	    }

	}
	
	//Redirect to return page
	function redirect($order, $redirect_url) {
		return '<script language="JavaScript">
					window.opener.location.href="'.$redirect_url.'";	
					self.close();
				</script>';
	}

	 // get all pages
    function get_pages($title = false, $indent = true) {
        $wp_pages = get_pages('sort_column=menu_order');
        $page_list = array();
        if ($title) $page_list[] = $title;
        foreach ($wp_pages as $page) {
            $prefix = '';
            // show indented child pages?
            if ($indent) {
                $has_parent = $page->post_parent;
                while($has_parent) {
                    $prefix .=  ' - ';
                    $next_page = get_page($has_parent);
                    $has_parent = $next_page->post_parent;
                }
            }
            // add to page list array array
            $page_list[$page->ID] = $prefix . $page->post_title;
        }
        return $page_list;
    }

}

/**
* Add the Gateway to WooCommerce
**/
function woocommerce_add_eximbay_gateway($methods) {
     $methods[] = 'WC_Gateway_Eximbay';
     return $methods;
}
 
add_filter('woocommerce_payment_gateways', 'woocommerce_add_eximbay_gateway' );

}
